package com.ruixuan.isc.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.kuaishou.merchant.open.api.KsMerchantApiException;
import com.kuaishou.merchant.open.api.client.AccessTokenKsMerchantClient;
import com.kuaishou.merchant.open.api.common.utils.GsonUtils;
import com.kuaishou.merchant.open.api.request.order.OpenOrderCursorListRequest;
import com.kuaishou.merchant.open.api.request.order.OpenOrderDetailRequest;
import com.kuaishou.merchant.open.api.request.shop.OpenScoreMasterGetRequest;
import com.kuaishou.merchant.open.api.request.shop.OpenScoreShopGetRequest;
import com.kuaishou.merchant.open.api.response.order.OpenOrderCursorListResponse;
import com.kuaishou.merchant.open.api.response.order.OpenOrderDetailResponse;
import com.kuaishou.merchant.open.api.response.shop.OpenScoreMasterGetResponse;
import com.kuaishou.merchant.open.api.response.shop.OpenScoreShopGetResponse;
import com.ruixuan.common.utils.Check;
import com.ruixuan.common.utils.DateUtils;
import com.ruixuan.isc.constants.KuaiShouConstants;
import com.ruixuan.isc.entity.KuaishouAccessToken;
import com.ruixuan.isc.entity.KwaixiaodianOrderCursorList;
import com.ruixuan.isc.entity.KwaixiaodianShopScore;
import com.ruixuan.isc.mapper.KwaixiaodianOrderCursorListMapper;
import com.ruixuan.isc.service.IAccessTokenService;
import com.ruixuan.isc.service.IKwaixiaodianOrderCursorListService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * kwaixiaodian商品详情Service业务层处理
 *
 * @date 2024-10-28
 */
@Slf4j
@Service
public class KwaixiaodianOrderCursorListServiceImpl implements IKwaixiaodianOrderCursorListService {
    @Autowired
    private KwaixiaodianOrderCursorListMapper mapper;
    @Autowired
    private IAccessTokenService accessTokenService;

    /**
     * 添加数据 replace
     * 表:kwaixiaodian_item_get
     */
    @Override
    public void querykwaiOrderList(String shopId, Integer queryType, String beginDate, String endDate, String cursor) {
        try {
            Long beginTime = DateUtils.getStartLongTime(beginDate);
            Long endTime = DateUtils.getEndLongTime(endDate);
            KuaishouAccessToken token = accessTokenService.getKWaiAccessToken(shopId);
            if (Check.isNull(token)) {
                log.error("----kwaixiaodian获取订单列表，shopId：{} 没有token信息", shopId);
            }

            AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, token.getAppKey(), token.getSignSecret());
            OpenOrderCursorListRequest request = new OpenOrderCursorListRequest();
            request.setAccessToken(token.getAccessToken());
            request.setApiMethodVersion(1L);

            //订单状态，0未知 1 全部 2 待付款 3 待发货 4 待收货（已发货）5 已收货 6 交易成功订单 7 已关闭订单。若此API返回超时，请传入1后重试
            request.setOrderViewStatus(1);
            //每页请求数量 最多一页50条
            request.setPageSize(50);
            //1时间降序 2时间升序 默认降序
            request.setSort(1);
            //1按创建时间查找 2按更新时间查找 ；默认创建时间，值为1时只允许获取创建时间90天内的订单数据，值为2时仅允许获取更新时间90天内且创建时间240天内的订单数据
            request.setQueryType(queryType);
            //订单生成时间的开始时间，单位毫秒， 不能小于90天前，且需要小于结束时间
            request.setBeginTime(beginTime);
            //订单生成时间的截止时间，单位毫秒，与开始时间的时间范围不大于7天
            request.setEndTime(endTime);
            //分销类型 0-全部 1-普通订单 2-分销订单
            request.setCpsType(0);
            //游标内容 第一次传空串，之后传上一次的cursor返回值，若返回“nomore”则标识到底
            request.setCursor(cursor);
            OpenOrderCursorListResponse response = null;
            try {
                response = client.execute(request);
            } catch (KsMerchantApiException e) {
                e.printStackTrace();
            }
            JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
//            System.out.println(GsonUtils.toJSON(response));
            String code = jsonObject.getString("code");
            if ("1".equals(code)) {
                JSONObject data = jsonObject.getJSONObject("data");
                cursor = data.getString("cursor");
                JSONArray orderList = data.getJSONArray("orderList");
                List<KwaixiaodianOrderCursorList> orderCursorList = new ArrayList<>();
                for (int i = 0; i < orderList.size(); i++) {
                    JSONObject object = orderList.getJSONObject(i);
                    KwaixiaodianOrderCursorList order = new KwaixiaodianOrderCursorList(token, object);
                    orderCursorList.add(order);
                }
                if (Check.isNotNull(orderCursorList)) {
                    mapper.replaceBatchKWaixiaodianOrderCursorList(orderCursorList);
                }
            } else {
                log.error("===kwaixiaodian获取订单列表（open.order.cursor.list）失败，shopId:{}，信息：{}", shopId, jsonObject.getString("error_msg"));
            }
            if (!"nomore".equals(cursor)) {
                querykwaiOrderList(shopId, queryType, beginDate, endDate, cursor);
            }
        } catch (Exception e) {
            log.error("===kwaixiaodian获取订单列表异常 querykwaiOrderList");
            e.printStackTrace();
        }
    }

    @Override
    public void queryNowdayKWaiOrderList(String shopId, String cursor) {
        try {
            //2小时前 时间戳
            Long beginTime = DateUtils.getTimeStamp(DateUtils.getHourTime(-2));
            //当前时间
            Long endTime = DateUtils.getTimeStamp(DateUtils.getTime());
            KuaishouAccessToken token = accessTokenService.getKWaiAccessToken(shopId);
            if (Check.isNull(token)) {
                log.error("----kwaixiaodian当天获取订单列表，shopId：{} 没有token信息", shopId);
            }

            AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, token.getAppKey(), token.getSignSecret());
            OpenOrderCursorListRequest request = new OpenOrderCursorListRequest();
            request.setAccessToken(token.getAccessToken());
            request.setApiMethodVersion(1L);

            //订单状态，0未知 1 全部 2 待付款 3 待发货 4 待收货（已发货）5 已收货 6 交易成功订单 7 已关闭订单。若此API返回超时，请传入1后重试
            request.setOrderViewStatus(1);
            //每页请求数量 最多一页50条
            request.setPageSize(50);
            //1时间降序 2时间升序 默认降序
            request.setSort(1);
            //1按创建时间查找 2按更新时间查找 ；默认创建时间，值为1时只允许获取创建时间90天内的订单数据，值为2时仅允许获取更新时间90天内且创建时间240天内的订单数据
            request.setQueryType(1);
            //订单生成时间的开始时间，单位毫秒， 不能小于90天前，且需要小于结束时间
            request.setBeginTime(beginTime);
            //订单生成时间的截止时间，单位毫秒，与开始时间的时间范围不大于7天
            request.setEndTime(endTime);
            //分销类型 0-全部 1-普通订单 2-分销订单
            request.setCpsType(0);
            //游标内容 第一次传空串，之后传上一次的cursor返回值，若返回“nomore”则标识到底
            request.setCursor(cursor);
            OpenOrderCursorListResponse response = null;
            try {
                response = client.execute(request);
            } catch (KsMerchantApiException e) {
                e.printStackTrace();
            }
            JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
            String code = jsonObject.getString("code");
            if ("1".equals(code)) {
                JSONObject data = jsonObject.getJSONObject("data");
                cursor = data.getString("cursor");
                JSONArray orderList = data.getJSONArray("orderList");
                List<KwaixiaodianOrderCursorList> orderCursorList = new ArrayList<>();
                for (int i = 0; i < orderList.size(); i++) {
                    JSONObject object = orderList.getJSONObject(i);
                    KwaixiaodianOrderCursorList order = new KwaixiaodianOrderCursorList(token, object);
                    orderCursorList.add(order);
                }
                if (Check.isNotNull(orderCursorList)) {
                    mapper.replaceBatchKWaixiaodianOrderCursorList(orderCursorList);
                }
            } else {
                log.error("===kwaixiaodian当天获取订单列表（open.order.cursor.list）失败，shopId:{}，信息：{}", shopId, jsonObject.getString("error_msg"));
            }
            if (!"nomore".equals(cursor)) {
                queryNowdayKWaiOrderList(shopId, cursor);
            }
        } catch (Exception e) {
            log.error("===kwaixiaodian当天获取订单列表异常 querykwaiOrderList");
            e.printStackTrace();
        }
    }

    @Override
    public void insertKWaiShopOrder(JSONObject eventJSon) {
        JSONObject info = eventJSon.getJSONObject("info");
        String openId = eventJSon.getString("openId");
        Long oid = null;
        if (!Check.isNull(info)) {
            oid = info.getLong("oid");
            KuaishouAccessToken token = accessTokenService.getKWaiAccessTokenByOpenId(openId);
            AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, token.getAppKey(), token.getSignSecret());

            OpenOrderDetailRequest request = new OpenOrderDetailRequest();
            request.setAccessToken(token.getAccessToken());
            request.setApiMethodVersion(1L);
            request.setOid(oid);
            OpenOrderDetailResponse response = null;
            try {
                response = client.execute(request);
            } catch (KsMerchantApiException e) {
                e.printStackTrace();
            }
            JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
            String code = jsonObject.getString("code");
            if ("1".equals(code)) {
                JSONObject data = jsonObject.getJSONObject("data");
                KwaixiaodianOrderCursorList order = new KwaixiaodianOrderCursorList(token, data);
                mapper.insertKWaixiaodianOrderCursorList(order);
            } else {
                log.error("===kwaixiaodian新增订单（open.order.detail）失败，oid:{}，信息：{}", oid, jsonObject.getString("error_msg"));
            }
        }
    }

    @Override
    public void updateKWaiShopOrderStatus(JSONObject eventJSon) {
        try {
            JSONObject info = eventJSon.getJSONObject("info");
            if (!Check.isNull(info)) {
                Map<String, Object> map = new HashMap<>();
                Long createTime = eventJSon.getLong("createTime");
                if (!Check.isNull(createTime)) {
                    Long time = Long.valueOf(DateUtils.timestamptoStr(createTime));
                    map.put("time", time);
                }
                Long oid = info.getLong("oid");
                Integer status = info.getInteger("status");
                map.put("oid", oid);
                map.put("status", status);
                String event = eventJSon.getString("event");
                if ("kwaishop_order_paySuccess".equals(event)) {
                    //已支付消息
                    map.put("field", "pay_time");
                } else if ("kwaishop_order_delivering".equals(event)) {
                    //已发货消息
                    map.put("field", "send_time");
                } else if ("kwaishop_order_deliverySuccess".equals(event)) {
                    //已收货消息
                    map.put("field", "recv_time");
                }
                int i = mapper.updateKWaiShopOrderStatus(map);
                if (i <= 0) {
                    log.error("KWai_订单ID:{},状态:{} 修改失败", oid, status);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void queryMaster(String shopId) {
        KuaishouAccessToken token = accessTokenService.getKWaiAccessToken(shopId);
        if (Check.isNull(token)) {
            log.error("----kwaixiaodian获取带货口碑分信息失败，shopId：{} 没有token信息", shopId);
        }

        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, token.getAppKey(), token.getSignSecret());
        OpenScoreMasterGetRequest request = new OpenScoreMasterGetRequest();
        request.setAccessToken(token.getAccessToken());
        request.setApiMethodVersion(1L);
        OpenScoreMasterGetResponse response = null;
        try {
            response = client.execute(request);
        } catch (KsMerchantApiException e) {
            e.printStackTrace();
        }
        JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
        String code = jsonObject.getString("code");
        if ("1".equals(code)) {
            JSONObject data = jsonObject.getJSONObject("data");
            String scoreStr = null;
            JSONObject summary = data.getJSONObject("summary");
            if (Check.isNotNull(summary)) {
                scoreStr = summary.getString("scoreStr");
            }
            KwaixiaodianShopScore shopScore = mapper.getScore(shopId);
            if (Check.isNull(shopScore)) {
                shopScore = new KwaixiaodianShopScore();
                shopScore.setShopId(shopId);
                shopScore.setShopName(token.getShopName());
                shopScore.setCompanyId(token.getCompanyId());
                shopScore.setCompanyName(token.getCompanyName());
                shopScore.setLeaderName(token.getLeaderName());
                shopScore.setMasterScore(scoreStr);
                shopScore.setMasterScoreBody(data.toJSONString());
                mapper.insertKwaixiaodianShopScore(shopScore);
            } else {
                shopScore.setMasterScore(scoreStr);
                shopScore.setMasterScoreBody(data.toJSONString());
                mapper.updateKwaixiaodianShopScore(shopScore);
            }
        } else {
            log.error("===kwaixiaodian获取带货口碑分信息异常，shopId:{}，信息：{}", shopId, jsonObject.getString("error_msg"));
        }
    }

    @Override
    public void queryShop(String shopId) {
        KuaishouAccessToken token = accessTokenService.getKWaiAccessToken(shopId);
        if (Check.isNull(token)) {
            log.error("----kwaixiaodian获取店铺体验分信息，shopId：{} 没有token信息", shopId);
        }
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, token.getAppKey(), token.getSignSecret());
        OpenScoreShopGetRequest request = new OpenScoreShopGetRequest();
        request.setAccessToken(token.getAccessToken());
        request.setApiMethodVersion(1L);

        OpenScoreShopGetResponse response = null;
        try {
            response = client.execute(request);
        } catch (KsMerchantApiException e) {
            e.printStackTrace();
        }
        JSONObject jsonObject = JSONObject.parseObject(GsonUtils.toJSON(response));
        String code = jsonObject.getString("code");
        if ("1".equals(code)) {
            JSONObject data = jsonObject.getJSONObject("data");
            String scoreStr = null;
            JSONObject summary = data.getJSONObject("summary");
            if (Check.isNotNull(summary)) {
                scoreStr = summary.getString("scoreStr");
            }
            KwaixiaodianShopScore shopScore = mapper.getScore(shopId);
            if (Check.isNull(shopScore)) {
                shopScore = new KwaixiaodianShopScore();
                shopScore.setShopId(shopId);
                shopScore.setShopName(token.getShopName());
                shopScore.setCompanyId(token.getCompanyId());
                shopScore.setCompanyName(token.getCompanyName());
                shopScore.setLeaderName(token.getLeaderName());
                shopScore.setShopScore(scoreStr);
                shopScore.setShopScoreBody(data.toJSONString());
                mapper.insertKwaixiaodianShopScore(shopScore);
            } else {
                shopScore.setShopScore(scoreStr);
                shopScore.setShopScoreBody(data.toJSONString());
                mapper.updateKwaixiaodianShopScore(shopScore);
            }
        } else {
            log.error("===kwaixiaodian获取店铺体验分信息异常，shopId:{}，信息：{}", shopId, jsonObject.getString("error_msg"));
        }
    }

    @Override
    public List<JSONObject> queryItemReport(Map<String, Object> requestMap) {
        return mapper.queryItemReport(requestMap);
    }

}
