package com.ruixuan.open.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.kuaishou.merchant.open.api.KsMerchantApiException;
import com.kuaishou.merchant.open.api.client.AccessTokenKsMerchantClient;
import com.kuaishou.merchant.open.api.common.utils.GsonUtils;
import com.kuaishou.merchant.open.api.request.user.OpenUserInfoGetRequest;
import com.kuaishou.merchant.open.api.response.user.OpenUserInfoGetResponse;
import com.ruixuan.isc.constants.KuaiShouConstants;
import com.ruixuan.isc.entity.JYAccessToken;
import com.ruixuan.isc.mapper.AccessTokenMapper;
import com.ruixuan.open.entity.KuaishouOpenUserInfo;
import com.ruixuan.open.mapper.KuaishouOpenUserInfoMapper;
import com.ruixuan.open.service.IKuaishouOpenUserInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户公开信息Service业务层处理
 *
 * @author ruoyi
 * @date 2024-07-09
 */
@Slf4j
@Service
public class KuaishouOpenUserInfoServiceImpl implements IKuaishouOpenUserInfoService {
    @Autowired
    private KuaishouOpenUserInfoMapper kuaishouOpenUserInfoMapper;

    @Autowired
    private AccessTokenMapper accessTokenMapper;

    /**
     * 查询用户公开信息
     *
     * @param id 用户公开信息主键
     * @return 用户公开信息
     */
    @Override
    public KuaishouOpenUserInfo selectKuaishouOpenUserInfoById(Long id) {
        return kuaishouOpenUserInfoMapper.selectKuaishouOpenUserInfoById(id);
    }

    /**
     * 查询用户公开信息列表
     *
     * @param kuaishouOpenUserInfo 用户公开信息
     * @return 用户公开信息
     */
    @Override
    public List<KuaishouOpenUserInfo> selectKuaishouOpenUserInfoList(KuaishouOpenUserInfo kuaishouOpenUserInfo) {
        return kuaishouOpenUserInfoMapper.selectKuaishouOpenUserInfoList(kuaishouOpenUserInfo);
    }

    @Override
    public void insertKuaishouOpenUserInfo() {
        List<JYAccessToken> jyTokenInfos = accessTokenMapper.getJYTokenInfos();
        for (JYAccessToken tokenInfo : jyTokenInfos) {
            insertInfo(tokenInfo, null);
        }
    }

    private void insertInfo(JYAccessToken token, String cursor) {
        try {
            String appKey = token.getAppKey();
            String signSecret = token.getSignSecret();
            String accessToken = token.getAccessToken();
            AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, appKey, signSecret);

            OpenUserInfoGetRequest request = new OpenUserInfoGetRequest();
            request.setAccessToken(accessToken);
            request.setApiMethodVersion(1L);

            OpenUserInfoGetResponse response = client.execute(request);
            JSONObject resultJson = JSONObject.parseObject(GsonUtils.toJSON(response));
            String code = resultJson.getString("code");
            if ("1".equals(code)) {
                KuaishouOpenUserInfo userInfo = JSONObject.parseObject(resultJson.getJSONObject("data").toJSONString(), KuaishouOpenUserInfo.class);
                userInfo.setPromoterId(Long.valueOf(token.getPromoterId()));
                kuaishouOpenUserInfoMapper.insertKuaishouOpenUserInfo(userInfo);
            } else {
                log.error("===获取用户公开信息（open.user.info.get）失败，promoterId:{}，信息：{}", token.getPromoterId(), resultJson.getString("msg"));
            }
        } catch (KsMerchantApiException e) {
            e.printStackTrace();
        }
    }

}
